@@ -10,7 +10,7 @@ import sqlalchemy as sa
 from nose.tools import eq_, ok_
 from nose.plugins.skip import SkipTest
 from tornado.web import create_signed_value
-from six.moves.urllib_parse import urlencode
+from urllib.parse import urlencode, urljoin
 import gramex
 import gramex.config
 from gramex.cache import SQLiteStore
@@ -30,18 +30,18 @@ class TestSession(TestGramex):
 
     def test_session(self):
         r1 = self.session1.get(self.url + '?var=x')
-        self.assertIn('sid', r1.cookies)
+        self.assertIn('sid2', r1.cookies)
         self.data1 = json.loads(r1.text)
         self.assertIn('id', self.data1)
         eq_(self.data1['var'], 'x')
 
         r2 = self.session2.get(self.url)
-        self.assertIn('sid', r2.cookies)
+        self.assertIn('sid2', r2.cookies)
         self.data2 = json.loads(r2.text)
         self.assertIn('id', self.data2)
         self.assertNotIn('var', self.data2)
 
-        self.assertNotEqual(r1.cookies['sid'], r2.cookies['sid'])
+        self.assertNotEqual(r1.cookies['sid2'], r2.cookies['sid2'])
         self.assertNotEqual(self.data1['id'], self.data2['id'])
 
         # Test expiry date. It should be within a few seconds of now, plus expiry date
@@ -62,7 +62,7 @@ class TestSession(TestGramex):
         r = requests.get(self.url + '?var=x')
         cookies = {c.name: c for c in r.cookies}
         cookie = r.headers['Set-Cookie'].lower()
-        self.assertIn('sid', cookies)
+        self.assertIn('sid2', cookies)
         self.assertIn('httponly', cookie)
         self.assertIn('domain=.localhost.local', cookie)
         # HTTP requests should not have a secure flag
@@ -114,14 +114,14 @@ class AuthBase(TestGramex):
         r = self.login(*args, **kwargs)
         eq_(r.status_code, OK)
         self.assertNotRegexpMatches(r.text, 'error code')
-        eq_(r.url, server.base_url + check_next)
+        eq_(r.url, urljoin(server.base_url, check_next))
 
     def logout_ok(self, *args, **kwargs):
         check_next = kwargs.pop('check_next')
         # logout() does not accept user, password. So Just pass the kwargs
         r = self.logout(**kwargs)
         eq_(r.status_code, OK)
-        eq_(r.url, server.base_url + check_next)
+        eq_(r.url, urljoin(server.base_url, check_next))
 
     def unauthorized(self, *args, **kwargs):
         r = self.login(*args, **kwargs)
@@ -138,15 +138,15 @@ class AuthBase(TestGramex):
             if 'data' in kwargs:
                 data.update(kwargs.pop('data'))
             r = session.post(self.url, data=data, allow_redirects=False, **kwargs)
-            eq_(r.headers['Location'], url)
+            eq_(urljoin(server.base_url, r.headers['Location']), urljoin(server.base_url, url))
 
 
 class LoginMixin(object):
     def test_login(self):
         self.login_ok('alpha', 'alpha', check_next='/dir/index/')
-        old_sid = self.session.cookies['sid']
+        old_sid = self.session.cookies['sid2']
         self.login_ok('beta', 'beta', check_next='/dir/index/')
-        new_sid = self.session.cookies['sid']
+        new_sid = self.session.cookies['sid2']
         # Test session fixation: login changes sid
         self.assertNotEqual(old_sid, new_sid)
 
@@ -293,6 +293,10 @@ class TestSimpleAuth(AuthBase, LoginMixin, LoginFailureMixin):
             r = self.session.get(server.base_url + '/auth/session', params={'gramex-otp': otp})
             eq_(r.status_code, BAD_REQUEST)
 
+    def test_authorize(self):
+        # If an Auth handler has an auth:, the auth: is ignored. Auth handlers are always open
+        self.check('/auth/authorize')
+
 
 class TestExpiry(AuthBase):
     # Just apply LoginMixin tests to AuthBase
@@ -303,7 +307,7 @@ class TestExpiry(AuthBase):
 
     def check_expiry(self, days):
         to_expire = time.time() + days * 24 * 60 * 60
-        expires = {c.name: c.expires for c in self.session.cookies}.get('sid', 0)
+        expires = {c.name: c.expires for c in self.session.cookies}.get('sid2', 0)
         self.assertLess(abs(to_expire - expires), 2)
         session = self.session.get(server.base_url + '/auth/session').json()
         self.assertLess(abs(to_expire - session.get('_t', 0)), 2)
@@ -667,7 +671,8 @@ class TestAuthorize(DBAuthBase, LoginFailureMixin):
     def initialize(self, url, user='alpha', login_url='/login/', next_key='next'):
         self.session = requests.Session()
         r = self.session.get(server.base_url + url)
-        eq_(r.url, server.base_url + login_url + '?' + urlencode({next_key: url}))
+        eq_(r.url, server.base_url + login_url + '?' + urlencode({
+            next_key: server.base_url + url}))
         r = self.session.post(server.base_url + url)
         eq_(r.url, server.base_url + url)
         eq_(r.status_code, UNAUTHORIZED)
